@@ -3,11 +3,12 @@ package MooseX::Role::Cmd;
 use strict;
 use warnings;
 
+use Carp ();
 use IPC::Cmd ();
 use Moose::Role;
 use MooseX::Role::Cmd::Meta::Attribute::Trait;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 NAME
 
@@ -34,9 +35,9 @@ Use it somewhere else:
     use Cmd::Perl;
 
     my $perl = Cmd::Perl->new(e => q{'print join ", ", @ARGV'});
-    
+
     print $perl->run(qw/foo bar baz/);
-    
+
     # prints the STDOUT captured from running:
     # perl -e 'print join ", ", @ARGV' foo bar baz
 
@@ -114,18 +115,18 @@ sub run {
     my $cmd = $self->bin_name;
     my $full_path;
     if ( !( $full_path = IPC::Cmd::can_run($cmd) ) ) {
-        confess qq{couldn't find command '$cmd'};
+        Carp::confess(qq{couldn't find command '$cmd'});
     }
-    
+
     # build full list of cmd args from attrs
     @args = $self->cmd_args( @args );
-    
+
     #warn "CMD: " . $full_path . " " . join (" ", map { "'$_'"  } @args );
     my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
       IPC::Cmd::run( command => [ $full_path, @args ] );
 
     if ( !$success ) {
-        confess "error running '$full_path': " . $error_code;
+        Carp::confess("error running '$full_path': " . $error_code);
     }
 
     $self->stdout($stdout_buf);
@@ -145,11 +146,11 @@ sub cmd_args {
     # exclude this role's attributes from the flag list
     # could use custom metaclasses and introspection, but this will do for now
     my %non_flag   = map    { $_ => 1 } __PACKAGE__->meta->get_attribute_list;
-    
+
     my @flag_attrs = grep   { !$non_flag{$_->name} }
                      map    { $self->meta->get_attribute($_) }
                      $self->meta->get_attribute_list;
-    
+
     #####
     # IS: 2008/10/15
     # Changed the following to make a start on the suggestion above...
@@ -166,14 +167,14 @@ sub cmd_args {
 
 =head2 Setting the Executable
 
-By default the name of the binary executable is taken from the last part of the class name 
+By default the name of the binary executable is taken from the last part of the class name
 (in lower case). The path is set during the L<run> method by scanning through your current
 PATH for the given executable (see also the 'can_run' function from L<IPC::Cmd>)
 
     package MyApp::Commands::Scanner;
     use Moose;
     with 'MooseX::Role::Cmd';
-    
+
     $cmd = MyApp::Commands::Scanner->new();
     $cmd->bin_name
     # /path/to/scanner
@@ -209,18 +210,18 @@ These points are illustrated in the following example:
     package MyApp::Commands::Scanner;
     use Moose;
     with 'MooseX::Role::Cmd';
-    
+
     has 'i'       => ( is => 'rw', isa => 'Str',  default => 'input.txt' );
     has 'out'     => ( is => 'rw', isa => 'Str' );
     has 'verbose' => ( is => 'rw', isa => 'Bool', default => 1 );
     has 'level'   => ( is => 'rw', isa => 'Int' );
     has 'option'  => ( is => 'rw', isa => 'Str' );
-    
+
     has '_internal' => ( is => 'ro', isa => Str, reader => internal, default => 'foo' );
     # attribute names starting with '_' are not included
-    
+
     $scanner = MyApp::Commands::Scanner->new( output => '/tmp/scanner.log', level => 5 );
-    
+
     $scanner->run;
     # /path/to/scanner -i input.txt --out /tmp/scanner.log --verbose --level 5
 
@@ -247,7 +248,7 @@ form of multi-character options).
 =head3 cmdopt_name
 
 This lets you completely override the option name with whatever string you want
-    
+
     has 'option' => ( traits        => [ 'CmdOpt' ],
                       isa           => 'Bool',
                       cmdopt_name   => '+foo'
@@ -256,7 +257,7 @@ This lets you completely override the option name with whatever string you want
 
 =head3 cmdopt_env
 
-This will set an environment variable with the attribute name/value rather than pass 
+This will set an environment variable with the attribute name/value rather than pass
 it along as a command line param
 
     has 'home_dir' => ( traits      => [ 'CmdOpt' ],
@@ -264,7 +265,7 @@ it along as a command line param
                         cmdopt_env  => 'APP_HOME'
                         default     => '/my/app/home'
                     );
-    
+
     # ENV{APP_HOME} = /my/app/home
 
 See L<MooseX::Role::Cmd::Meta::Attribute::Trait>
@@ -280,18 +281,18 @@ to the given attribute name.
 
 sub _attr_to_cmd_options {
     my ( $self, $attr ) = @_;
-    
+
     my $attr_name = $attr->name;
-    
+
     # decide the default settings
     my $opt_prefix = length( $attr_name ) == 1 ? '-' : '--';
     my $opt_name   = $attr_name;
-    
+
     my $attr_value = $attr->get_value( $self );
-    
+
     # override defaults with Traits
     if ( $attr->does('MooseX::Role::Cmd::Meta::Attribute::Trait') ) {
-        
+
         # deal with $ENV
         if ($attr->has_cmdopt_env) {
             my $env_key   = $attr->cmdopt_env;
@@ -305,32 +306,32 @@ sub _attr_to_cmd_options {
         if ($attr->has_cmdopt_prefix) {
             $opt_prefix = $attr->cmdopt_prefix;
         }
-        
+
         if ($attr->has_cmdopt_name) {
             $opt_prefix = '';                   # name overrides prefix
             $opt_name   = $attr->cmdopt_name;
         }
     }
-    
+
     # create the full option name
     my $opt_fullname = $opt_prefix . $opt_name;
-    
+
     my @options = ();
     if ( $attr->type_constraint->is_a_type_of( 'Bool' ) ) {
         push @options, ( $opt_fullname )
             if $attr_value;                             # only add if attr is true
     }
     else {
-        
+
         if ( defined $attr_value                        # only add if attr value is defined
-             && 
+             &&
              $attr_name !~ / ^ _ /xms                   # and attr name doesn't start with '_'
            )
         {
             push @options, ( $opt_fullname, $attr_value )
         }
     }
-    
+
     return wantarray ? @options : \@options;
 }
 
